@@ -2,7 +2,7 @@ from enum import Enum
 
 from .command import Command
 from .fields import (Enum as EnumField, Int, Bool, Str, Time12H, Time,
-                     DateTime, Bitmask, IPAddress)
+                     DateTime, Bitmask, IPAddress, VideoWallModel)
 from .utils import parse_enum_bitmask
 
 
@@ -612,12 +612,12 @@ class TIMER_15(Command):
 
     Note: This depends on product and will not work on older versions.
 
-    ON_TIME/OFF_TIME - Turn ON/OFF display at specific time of day
+    ON_TIME/OFF_TIME: turn ON/OFF display at specific time of day
 
-    ON_ACTIVE/OFF_ACTIVE - If timer is not active, values are ignored,
+    ON_ACTIVE/OFF_ACTIVE: if timer is not active, values are ignored,
     so there may be only OFF timer, ON timer, or both.
 
-    REPEAT - On which day timer is enabled
+    REPEAT: On which day timer is enabled
     (combined with HOLIDAY_APPLY and MANUAL_WEEKDAY)
     """
     CMD = Int('TIMER_ID', range(1, 8))
@@ -753,13 +753,13 @@ class HOLIDAY_SET(Command):
     CMD = 0xA8
     GET, SET = False, True
 
-    class HOLIDAY_CHANGE(Enum):
+    class HOLIDAY_MANAGE(Enum):
         ADD = 0x00
         DELETE = 0x01
         DELETE_ALL = 0x02
 
     DATA = [
-        HOLIDAY_CHANGE,
+        HOLIDAY_MANAGE,
         Int('START_MONTH', range(13)),
         Int('START_DAY', range(32)),
         Int('END_MONTH', range(13)),
@@ -767,24 +767,14 @@ class HOLIDAY_SET(Command):
         ]
 
 
-class HOLIDAY_GET_COUNT(Command):
-    CMD = 0xA9
-    GET, SET = True, False
-
-    DATA = [
-        Int('HOLIDAY_COUNT'),
-    ]
-
-    @classmethod
-    def parse_response_data(cls, data):
-        assert len(data) == 5, 'Unexpected response data length'
-        assert data[1:] == bytes([0, 0, 0, 0]), 'Unexpected response data'
-        return super().parse_response_data(data[:1])
-
-
 class HOLIDAY_GET(Command):
+    """
+    Get the device holiday schedule.
+
+    If INDEX is not specified, returns total number of Holiday Information.
+    """
     CMD = 0xA9
-    GET, SET = False, True
+    GET, SET = True, True
 
     DATA = [
         Int('INDEX'),
@@ -797,6 +787,12 @@ class HOLIDAY_GET(Command):
         Int('END_DAY'),
     ]
 
+    @classmethod
+    def parse_response_data(cls, data):
+        if data[1:] == bytes([0, 0, 0, 0]):
+            return [int(data[0])]
+        return super().parse_response_data(data)
+
 
 class VIRTUAL_REMOTE(Command):
     """
@@ -1063,3 +1059,60 @@ class RGB(Command):
         Int('_IGNORE', range(1)),
         Int('RED_GAIN'), Int('GREEN_GAIN'), Int('BLUE_GAIN'),
     ]
+
+
+class VIDEO_WALL_STATE(Command):
+    """
+    Get or set the device in video wall state.
+    This will split the primary input source into smaller N number of squares
+    and display them instead.
+
+    Note: The device needs to be capable of this operation.
+    Usually a primary high resolution source signal is daisy chained
+    to lower resolution displays in a video wall using HDMI/DP.
+    """
+    CMD = 0x84
+    GET, SET = True, True
+
+    class VIDEO_WALL_STATE(Enum):
+        OFF = 0x00
+        ON = 0x01
+
+    DATA = [VIDEO_WALL_STATE]
+
+
+class VIDEO_WALL_MODE(Command):
+    """
+    Get or set the device in aspect ratio of the video wall.
+
+    FULL: stretch input source to fill display
+
+    NATURAL: Keep aspect ratio of input source; do not fill display.
+
+    Note: Needs VIDEO_WALL_STATE to be ON.
+    """
+    CMD = 0x5C
+    GET, SET = True, True
+
+    class VIDEO_WALL_MODE(Enum):
+        NATURAL = 0x00
+        FULL = 0x01
+
+    DATA = [VIDEO_WALL_MODE]
+
+
+class VIDEO_WALL_MODEL(Command):
+    """
+    Get or set video wall model.
+
+    MODEL: Size of the wall in (x, y) coordinates; ie. "2,2" or "4,1"
+
+    SERIAL: Serial number - position of the display in the video wall,
+    counting from the first display.
+
+    Note: Needs VIDEO_WALL_STATE to be ON.
+    """
+    CMD = 0x89
+    GET, SET = True, True
+
+    DATA = [VideoWallModel('MODEL'), Int('SERIAL', range(1, 256))]
